
import React from 'react'
import { createRoot } from 'react-dom/client'
import './index.css'

console.log('React version:', React.version);

const initializeApp = async () => {
  try {
    // Performance timing
    const startTime = performance.now();
    
    // Set initial language and theme from localStorage or fallback to defaults
    const initialLang = localStorage.getItem('lang') || 'he';
    const initialTheme = localStorage.getItem('theme') || 'dark';

    // Set dark mode and initial language/direction with performance optimization
    const html = document.documentElement;
    html.classList.add(initialTheme);
    html.lang = initialLang;
    html.dir = initialLang === 'he' ? 'rtl' : 'ltr';
    html.classList.toggle('rtl', initialLang === 'he');
    localStorage.setItem('theme', initialTheme);
    localStorage.setItem('lang', initialLang);

    // Ensure we have a valid root element
    const rootElement = document.getElementById("root");
    if (!rootElement) {
      throw new Error('Root element not found');
    }

    console.log('Creating React root...');
    
    // Dynamic import with better error handling
    const { default: App } = await import('./App').catch(error => {
      console.error('Failed to load App component:', error);
      throw error;
    });
    
    // Create root and render app with performance optimization
    const root = createRoot(rootElement, {
      // Enable concurrent features for better performance
      identifierPrefix: 'cyberteam360-'
    });
    
    console.log('Rendering App component...');
    root.render(
      <React.StrictMode>
        <App />
      </React.StrictMode>
    );

    const endTime = performance.now();
    console.log(`App initialized successfully in ${(endTime - startTime).toFixed(2)}ms`);

    // Register service worker for better caching (production only) - heavily deferred
    if ('serviceWorker' in navigator && import.meta.env.MODE === 'production') {
      // Wait for all critical resources to load first
      setTimeout(() => {
        navigator.serviceWorker.register('/service-worker.js', {
          scope: '/',
          updateViaCache: 'none'
        }).then(registration => {
          console.log('ServiceWorker registered successfully');
          
          // Check for updates every 24 hours
          setInterval(() => {
            registration.update();
          }, 24 * 60 * 60 * 1000);
        }).catch(error => {
          console.error('ServiceWorker registration failed:', error);
        });
      }, 10000); // Increased delay to 10 seconds
    }

    // Performance metrics logging - Fixed TypeScript error
    if ('performance' in window && 'getEntriesByType' in performance) {
      setTimeout(() => {
        const perfData = performance.getEntriesByType('navigation')[0] as PerformanceNavigationTiming;
        if (perfData) {
          console.log('Performance metrics:', {
            domContentLoaded: perfData.domContentLoadedEventEnd - perfData.domContentLoadedEventStart,
            loadComplete: perfData.loadEventEnd - perfData.loadEventStart,
            firstByte: perfData.responseStart - perfData.requestStart,
            domInteractive: perfData.domInteractive - perfData.fetchStart
          });
        }
      }, 1000);
    }

  } catch (error) {
    console.error('Error initializing app:', error);
    // Enhanced fallback with better error display
    const rootElement = document.getElementById("root");
    if (rootElement) {
      rootElement.innerHTML = `
        <div style="
          padding: 20px; 
          text-align: center; 
          color: #ef4444; 
          font-family: Heebo, sans-serif;
          background: #0f172a;
          min-height: 100vh;
          display: flex;
          flex-direction: column;
          align-items: center;
          justify-content: center;
        ">
          <h1 style="color: #00d4ff; margin-bottom: 20px;">CyberTeam360</h1>
          <p style="margin-bottom: 10px;">שגיאה בטעינת האפליקציה. אנא רענן את הדף.</p>
          <p style="margin-bottom: 20px;">Application failed to load. Please refresh the page.</p>
          <button onclick="window.location.reload()" style="
            background: #00d4ff;
            color: #0f172a;
            border: none;
            padding: 10px 20px;
            border-radius: 5px;
            cursor: pointer;
            font-family: Heebo, sans-serif;
          ">רענן דף / Refresh Page</button>
        </div>
      `;
    }
  }
};

// Initialize with better performance handling
if (document.readyState === 'loading') {
  document.addEventListener('DOMContentLoaded', initializeApp);
} else {
  // Use requestIdleCallback if available for better performance
  if ('requestIdleCallback' in window) {
    requestIdleCallback(initializeApp, { timeout: 1000 });
  } else {
    setTimeout(initializeApp, 0);
  }
}
